from dataclasses import dataclass, field

from unctl.lib.checks.check_report import CheckReport


# TBD lookup the inventory and make sure this matches up
def get_object_id(object_name):
    return object_name.split("/")[-1]


@dataclass
class CheckReportK8s(CheckReport):
    """Contains the AWS Check's finding information."""

    resource_id: str = ""
    resource_name: str = ""
    resource_details: str = ""
    resource_tags: list = field(default_factory=list)
    resource_namespace: str = ""
    resource_pod: str = ""
    resource_node: str = ""
    resource_cluster: str = ""
    resource_service: str = ""
    resource_pvc: str = ""
    resource_container: str = ""
    resource_selector: str = ""
    resource_dep_type: str = ""
    resource_dep_name: str = ""
    resource_configmap: str = ""

    _depends_on: list = field(default_factory=list)

    def __init__(self, metadata):
        super().__init__(metadata)

        self.check_cli_output = {}
        self.diagnostics_cli_output = {}
        self.recommendations_output = {}

    @property
    def display_object(self) -> str:
        fmt_view = ""
        fmt_view += f'\n  "Status":  "{self.status}"'
        fmt_view += f'\n  "Check":  "{self.check_metadata.CheckTitle}"'
        fmt_view += f'\n  "Namespace":  "{self.resource_namespace}"'
        fmt_view += f'\n  "Object":  "{self.resource_name}"'
        fmt_view += f'\n  "Severity":  "{self.check_metadata.Severity}"'
        fmt_view += f'\n  "Summary":  "{self.status_extended}"'
        return fmt_view

    @property
    def display_row(self):
        return [
            self.resource_namespace,
            self.resource_name,
            self.check_metadata.CheckTitle,
            self.check_metadata.Severity,
            self.status,
            self.status_extended,
        ]

    @property
    def object_id(self) -> str:
        return self.resource_id

    @property
    def object_name(self) -> str:
        return self.resource_name
